@@ -1,29 +1,25 @@
-import delphai_utils.patches.aiokafka_patch
 import asyncio
-from logging import Logger
-from aioprometheus.collectors import Histogram
-from deepmerge import always_merger
-from delphai_utils.logging import default_config as default_logging_config, logging
-from abc import abstractmethod, abstractproperty
-import faust
+import logging
 import socket
+from abc import abstractmethod, abstractproperty
 from dataclasses import dataclass, field
-from typing import Any, Dict, List, Optional, TypeVar, Type, Union
-from delphai_utils.config import get_config
+from timeit import default_timer
+from typing import Dict, List, Optional, Type, TypeVar, Union
+
+import faust
+from aioprometheus import Counter, Service, Summary
+from aioprometheus.collectors import Histogram
+from betterproto import Message
+from confluent_kafka.admin import AdminClient, NewTopic
+from dacite import from_dict
+from faust.serializers import Codec
+from faust.streams import Stream
 from faust.types import CodecArg
 from faust.types.models import ModelT
-from faust.streams import Stream
-from confluent_kafka.admin import AdminClient, NewTopic
-from betterproto import Message
-from faust.serializers import Codec
-from dacite import from_dict
+
 from delphai_utils.config import get_config
-import coloredlogs
-from aioprometheus import Service, Counter, Summary
-from timeit import default_timer
 
-
-logging.getLogger("aiohttp").setLevel(logging.ERROR)
+logger = logging.getLogger(__name__)
 
 
 def is_port_free(host, port):
@@ -50,9 +46,9 @@ def find_free_port(start: int, host="127.0.0.1", num_tries=4) -> int:
         if is_port_free(host, port):
             return port
         else:
-            logging.info(f"Port {port} already in use.")
+            logger.info(f"Port {port} already in use.")
     message = f"No free port found in range [{start}, {start + num_tries - 1}]"
-    logging.error(message)
+    logger.error(message)
     raise NoPortFoundError(message)
 
 
@@ -97,7 +93,6 @@ class FaustAgent:
     input_value_serializer: CodecArg
     output_value_serializer: CodecArg
     agent: faust.Agent
-    logger: Logger
     metrics: Metrics
     metrics_server: Service
 
@@ -157,7 +152,7 @@ class FaustAgent:
         pass
 
     async def on_start(self):
-        self.logger.info(f"started agent {self.agent_id}")
+        logger.info(f"started agent {self.agent_id}")
 
     async def after_attach(self):
         pass
@@ -176,32 +171,18 @@ class FaustAgent:
 class FaustApp:
     app: faust.App
     worker: faust.Worker
-    logging_config: Dict
     faust_config: Dict
     metrics: Service = Service()
     pipeline_name: str
 
     async def on_startup_finished(self):
-        self.logger.info(f"started app {self.app._conf.id}")
+        logger.info(f"started app {self.app._conf.id}")
 
     async def on_start(self):
-        self.logger.info(f"starting app {self.app._conf.id}")
+        logger.info(f"starting app {self.app._conf.id}")
 
     async def on_shutdown(self):
-        self.logger.info(f"shutting down {self.app._conf.id}")
-
-    def on_setup_root_logger(self, logger: logging.Logger, level: int):
-        standard_format = self.logging_config["formatters"]["standard"]
-        effective_level = self.logger.getEffectiveLevel()
-        logger.setLevel(effective_level)
-        coloredlogs.install(
-            level=effective_level,
-            fmt=standard_format["format"],
-            datefmt=standard_format["datefmt"],
-            logger=logger,
-        )
-        self.worker._disable_spinner_if_level_below_WARN(effective_level)
-        self.worker._setup_spinner_handler(logger, effective_level)
+        logger.info(f"shutting down {self.app._conf.id}")
 
     def __init__(
         self, pipeline_name: str, broker: str, step: Union[str, None] = None
@@ -222,32 +203,15 @@ class FaustApp:
             id=app_id, broker=broker, web_enabled=False, **self.faust_config
         )
         loop = asyncio.get_event_loop()
-        provided_logging_config = {}
-        try:
-            provided_logging_config = get_config("logging")
-        except Exception:
-            pass
-        default_logging_config["disable_existing_loggers"] = False
-        default_logging_config["formatters"]["standard"][
-            "format"
-        ] = "[%(asctime)s] [%(levelname)s] [%(name)s] %(message)s"
-        default_logging_config["loggers"]["faust"] = {"level": logging.ERROR}
-        default_logging_config["loggers"]["aiokafka"] = {"level": logging.ERROR}
-        default_logging_config["loggers"]["mode"] = {"level": logging.ERROR}
-        self.logging_config = always_merger.merge(
-            default_logging_config, provided_logging_config
-        )
+
         self.worker = faust.Worker(
             self.app,
             loop=loop,
-            loglevel=logging.INFO,
-            logging_config=self.logging_config,
+            override_logging=False,
         )
         self.worker.on_startup_finished = self.on_startup_finished
         self.worker.on_start = self.on_start
         self.worker.on_shutdown = self.on_shutdown
-        self.worker.on_setup_root_logger = self.on_setup_root_logger
-        self.logger = logging.getLogger(self.pipeline_name)
 
     def start(self, agents: List[FaustAgent]):
         try:
@@ -260,11 +224,11 @@ class FaustApp:
                 tasks.append(self.attach(agent))
             metrics_port = find_free_port(9191)
             asyncio.get_event_loop().create_task(self.metrics.start(port=metrics_port))
-            self.logger.info(f"started metrics server on port {metrics_port}")
+            logger.info(f"started metrics server on port {metrics_port}")
             self.worker.loop.run_until_complete(asyncio.gather(*tasks))
             self.worker.execute_from_commandline()
         except KeyboardInterrupt:
-            self.logger.info("keyboard interrupt received")
+            logger.info("keyboard interrupt received")
 
     def get_step_config(self, step: str) -> Step:
         step_config = next((s for s in get_config("steps") if s["name"] == step), None)
@@ -273,27 +237,26 @@ class FaustApp:
     def create_topic(self, broker: str, step: str):
         step_config = self.get_step_config(step)
         client = AdminClient({"bootstrap.servers": broker.replace("kafka://", "")})
-        topics = list(client.list_topics().topics.keys())
+        topics = client.list_topics().topics
         topic_names = [f"{self.pipeline_name}.{step_config.name}"]
         for table in step_config.tables:
             table_topic_name = f"{self.pipeline_name}-{table}-changelog"
             topic_names.append(table_topic_name)
         for topic_name in topic_names:
             if topic_name not in topics:
-                self.logger.info(
+                logger.info(
                     f"creating topic {topic_name} with {step_config.partitions} partitions"
                 )
                 resp = client.create_topics(
-                    [NewTopic(topic_name, step_config.partitions, 1)]
+                    [NewTopic(topic_name, step_config.partitions, replication_factor=1)]
                 )
                 resp[topic_name].result()
             else:
-                self.logger.info(f"topic {topic_name} already exists")
+                logger.info(f"topic {topic_name} already exists")
 
     async def attach(self, agent: FaustAgent):
         agent.step_config = self.get_step_config(agent.step)
         agent.agent_id = f"{self.pipeline_name}.{agent.step}"
-        agent.logger = logging.getLogger(f"{self.pipeline_name}] [{agent.step}")
         agent.input_topic = self.app.topic(
             agent.agent_id,
             value_type=agent.input_value_type,
